==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
export let WebDockingIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockingIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockingIndicatorDescriptionMetadata.a == null) {
                WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
            }
            if (a.j(WebDockingIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDockingIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockingIndicator");
            a.item("Position", "ExportedType:string:DockingIndicatorPosition");
            a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
            a.item("IsRoot", "Boolean");
        }
        static d(a) {
            WebDockingIndicatorDescriptionMetadata.b(a);
            a.aa("WebDockingIndicator", () => new WebDockingIndicatorDescription());
            a.z("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
        }
    }
    WebDockingIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
export let WebDockingIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockingIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockingIndicatorDescriptionMetadata.a == null) {
                WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
            }
            if (a.k(WebDockingIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDockingIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockingIndicator");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Position", "ExportedType:string:DockingIndicatorPosition");
            a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
            a.item("IsRoot", "Boolean");
        }
        static d(a) {
            WebDockingIndicatorDescriptionMetadata.b(a);
            a.ac("WebDockingIndicator", () => new WebDockingIndicatorDescription());
            a.ab("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
        }
    }
    WebDockingIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
})();
